/*
 *    snake - a videogame derived from Q-Basic nibbles
 *    Copyright (C) 1999 Cyberandro J.K. Starrik
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include "sins.h"
#include <errno.h>
#include <stdio.h>		/* fopen, fclose, ...   */
#include <sys/types.h>		/* getpwuid, ...   */
#include <sys/stat.h>		/* stat, ...   */

#define DEBUG_CONFIG

/*
 * pubblic data 
 */
char *configfile;

/*
 * public_functions 
 */
int parse_config ();
int CMD_source (char *);

/*
 * private functions 
 */
static char *get_config_path (void);

static char *
get_config_path ()
{
  char *confpath;

  /*
   * configfile as been specified on command line 
   */
  if (configfile)
    return configfile;

  /*
   * environmental variable SNAKE_CONF is set 
   */
  confpath = getenv ("SNAKE_CONF");
  if (confpath)
    return confpath;

  return NULL;

}

/*
 * Evaluate commands from a file
 */
int
CMD_source (char *arg)
{
  char buf[MAXCMDLINELEN];
  FILE *stream;

  if (!arg)
    return -1;

  /*
   * Open file for reading or complain
   */
  stream = fopen (arg, "r");
  if (!stream)
    {
      message ("Can't open %s: %s", arg, strerror (errno));
      return 0;
    }

  /*
   * Scan the whole file for commands
   */
  while (fgets (buf, MAXCMDLINELEN, stream))
    {
      parse_command (buf);
    }

  fclose (stream);

  return 1;
}

int
parse_config ()
{
  char *confpath;

  confpath = get_config_path ();
  if (!confpath)
    {
      message ("No configuration file");
      return 0;
    }

  return CMD_source (confpath);
}
